.. _spkg_types_python_dateutil:

types_python_dateutil: Typing stubs for python-dateutil
=======================================================

Description
-----------

Typing stubs for python-dateutil

License
-------

Apache-2.0 license

Upstream Contact
----------------

https://pypi.org/project/types-python-dateutil/



Type
----

standard


Dependencies
------------

- $(PYTHON)
- :ref:`spkg_pip`

Version Information
-------------------

package-version.txt::

    2.9.0.20240316

version_requirements.txt::

    types-python-dateutil

Equivalent System Packages
--------------------------

(none known)
